@@ -108,3 +108,23 @@ class MainExcel():
             print('拆分结束')
         else:
             raise Exception(f"你的文件只有一个sheet，难道还要拆分吗？我做不到啊~~~，你的文件名{file_path}")
+
+    def merge2sheet(self, dir_path, output_sheet_name: str, output_excel_name):
+        for root, dirs, files in os.walk(dir_path):
+            path = Path(dir_path)
+            print(f'正在合并的文件有：{files}')
+            print(f'合并后的文件名是：{output_excel_name}')
+            print(f'合并后的sheet名是：{output_sheet_name}')
+            df_list = []
+            for file in files:
+                if file.endswith("xlsx") or file.endswith("xls"):
+                    excel_path = (path / file)
+                    df_list.append(pd.read_excel(excel_path))
+            res = pd.concat(df_list)
+            res.to_excel(
+                (path / (output_excel_name + '.xlsx')),
+                sheet_name=output_sheet_name,
+                index=False  # 不保留index
+            )
+
+            pass
